%define        majversion  %(echo %version | cut -d. -f 1-2)
%define        apiver %(echo %version | cut -d. -f 1).0

Name:          libsigc++
Version:       3.6.0
Release:       1mamba
Summary:       The Typesafe Signal Framework for C++
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://libsigcplusplus.github.io/libsigcplusplus/
Source:        http://ftp.acc.umu.se/pub/GNOME/sources/libsigc++/%{majversion}/libsigc++-%{version}.tar.xz
License:       LGPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END

%description
Libsigc++ implements a typesafe callback system for standard C++.
It allows you to define signals and to connect those signals to any callback function, either global or a member function, regardless of whether it is static or virtual.
It also contains adaptor classes for connection of dissimilar callbacks and has an ease of use unmatched by other C++ callback libraries.
Features:
* Compile time typesafe callbacks (faster than run time checks)
* Typesafety violations report line number correctly with template names (no tracing template failures into headers)
* No compiler extensions or meta compilers required
* Proper handling of dynamic objects and signals (deleted objects will not cause seg faults)
* Extendable API at any level: signal, slot, connection and trackable
* Extensions do not require alteration of basic components
* User definable accumulators
* A variety of adaptors to change the callback signature: bind, hide, retype, compose and lambda call groups
* Various compilers and platforms are supported: gcc, cygwin, mingw32, MS .NET 2003, Sun Forte C++, Compaq C++, Intel C++

%package devel
Group:         Development/Libraries
Summary:       Static libraries and headers for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
Libsigc++ implements a typesafe callback system for standard C++.
It allows you to define signals and to connect those signals to any callback function, either global or a member function, regardless of whether it is static or virtual.
It also contains adaptor classes for connection of dissimilar callbacks and has an ease of use unmatched by other C++ callback libraries.
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q

%build
%meson \
   -Dbuild-documentation=true

%meson_build

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%meson_install

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_libdir}/libsigc-%{apiver}.so.*
%doc COPYING

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/sigc++-%{apiver}
%{_includedir}/sigc++-%{apiver}/sigc++/*
%{_libdir}/sigc++-%{apiver}/include/sigc++config.h
%{_libdir}/libsigc-%{apiver}.so
%dir %{_libdir}/sigc++-%{apiver}
%{_libdir}/pkgconfig/*.pc
%{_datadir}/devhelp/books/libsigc++-%{apiver}/libsigc++-%{apiver}.devhelp2
%dir %{_defaultdocdir}/libsigc++-%{apiver}
%{_defaultdocdir}/libsigc++-%{apiver}/*
%doc ChangeLog README.md NEWS

%changelog
* Sun Oct 08 2023 Automatic Build System <autodist@mambasoft.it> 3.6.0-1mamba
- automatic version update by autodist

* Sat Dec 24 2022 Automatic Build System <autodist@mambasoft.it> 3.4.0-1mamba
- automatic version update by autodist

* Sat Feb 12 2022 Automatic Build System <autodist@mambasoft.it> 3.2.0-1mamba
- automatic version update by autodist

* Thu May 20 2021 Automatic Build System <autodist@mambasoft.it> 3.0.7-1mamba
- automatic version update by autodist

* Sun Feb 07 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 3.0.6-1mamba
- update to 3.0.6

* Wed Sep 09 2020 Automatic Build System <autodist@mambasoft.it> 2.10.3-1mamba
- automatic update by autodist

* Sun Aug 04 2019 Automatic Build System <autodist@mambasoft.it> 2.10.2-1mamba
- automatic update by autodist

* Wed Oct 19 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.10.0-1mamba
- update to 2.10.0

* Sat Apr 30 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.8.0-1mamba
- update to 2.8.0

* Fri Dec 25 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.2-2mamba
- rebuilt with gcc 5.3.0

* Sun Nov 29 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 2.6.2-1mamba
- update to 2.6.2

* Tue Mar 10 2015 Automatic Build System <autodist@mambasoft.it> 2.4.1-1mamba
- automatic update by autodist

* Tue Sep 16 2014 Automatic Build System <autodist@mambasoft.it> 2.4.0-1mamba
- automatic version update by autodist

* Sat Aug 02 2014 Automatic Build System <autodist@mambasoft.it> 2.3.2-1mamba
- automatic update by autodist

* Thu Oct 18 2012 Automatic Build System <autodist@mambasoft.it> 2.3.1-1mamba
- automatic version update by autodist

* Tue Sep 25 2012 Automatic Build System <autodist@mambasoft.it> 2.2.11-1mamba
- update to 2.2.11

* Mon Aug 08 2011 Automatic Build System <autodist@mambasoft.it> 2.2.10-1mamba
- automatic version update by autodist

* Tue Mar 08 2011 Automatic Build System <autodist@mambasoft.it> 2.2.9-1mamba
- automatic update by autodist

* Mon Oct 25 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.8-2mamba
- rebuilt to add pkgconfig provides

* Fri Jun 04 2010 Automatic Build System <autodist@mambasoft.it> 2.2.8-1mamba
- automatic update to 2.2.8 by autodist

* Mon May 31 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.7-1mamba
- update to 2.2.7
- package renamed from libsigc++2

* Tue Sep 29 2009 Automatic Build System <autodist@mambasoft.it> 2.2.4.2-1mamba
- automatic update by autodist

* Wed Jan 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.3-1mamba
- automatic update by autodist

* Sun Sep 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.2.2-1mamba
- update to 2.2.2

* Wed Jun 18 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.18-2mamba
- fixed descriptions formatting
- updated maintainer

* Wed Jun 18 2008 Tiziana Ferro <tiziana.ferro@email.it> 2.0.18-1mamba
- update to 2.0.18
- add buildrequirements

* Thu Jun 15 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.0.17-1qilnx
- update to version 2.0.17 by autospec

* Thu Dec 16 2004 Davide Madrisan <davide.madrisan@qilinux.it> 2.0.3-2qilnx
- specfile cleanups
- conditionally remove the build root directory
- own `[lib]sigc-2.0' directories (devel package)
- package rebuild and moved to QiLinux official repository

* Wed Dec 15 2004 Matteo Bernasconi <voyagernm@virgilio.it> 2.0.3-1qilnx
- first build
